==> haskell-pretty-show-1.10-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-show
version:              1.10
visibility:           public
id:                   pretty-show-1.10-JwphvxEdk99BsHrT870tUy
key:                  pretty-show-1.10-JwphvxEdk99BsHrT870tUy
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/pretty-show
synopsis:
    Tools for working with derived `Show` instances and generic
    inspection of values.

description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.

category:             Text
abi:                  b74f07b76e9ae18562e6c411a93e7b73
exposed:              True
exposed-modules:      Text.Show.Pretty
hidden-modules:
    Text.Show.Html Text.Show.Parser Text.Show.Value Text.Show.PrettyVal
    Paths_pretty_show

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pretty-show-1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pretty-show-1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-show
hs-libraries:         HSpretty-show-1.10-JwphvxEdk99BsHrT870tUy
depends:
    array-0.5.4.0 base-4.16.4.0 filepath-1.4.2.2 ghc-prim-0.8.0
    haskell-lexer-1.1.1-K7I6uqCDpmCAWLRFKaxnTu pretty-1.1.3.6
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html:         /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-show-1.10-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-show
version:              1.10
visibility:           public
id:                   pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
key:                  pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
homepage:             http://wiki.github.com/yav/pretty-show
synopsis:
    Tools for working with derived `Show` instances and generic
    inspection of values.

description:
    We provide a library and an executable for working with derived '\''Show'\''
    instances. By using the library, we can parse derived '\''Show'\'' instances into a
    generic data structure. The @ppsh@ tool uses the library to produce
    human-readable versions of '\''Show'\'' instances, which can be quite handy for
    debugging Haskell programs.  We can also render complex generic values into
    an interactive Html page, for easier examination.

category:             Text
abi:                  e61ff99bc6f396f9ab47d5e7defc3741
exposed:              True
exposed-modules:      Text.Show.Pretty
hidden-modules:
    Text.Show.Html Text.Show.Parser Text.Show.Value Text.Show.PrettyVal
    Paths_pretty_show

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pretty-show-1.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pretty-show-1.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pretty-show-1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-show
hs-libraries:         HSpretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
depends:
    array-0.5.4.0 base-4.17.2.1 filepath-1.4.2.2 ghc-prim-0.9.1
    haskell-lexer-1.1.1-Hpax8yMtr9r8FzGXIYjm8Z pretty-1.1.3.6
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-pretty-show/html/pretty-show.haddock
haddock-html:         /usr/share/doc/haskell-pretty-show/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
